{% extends "layout.html" %}
{% block content %}
  <div class="container">
    <div class="row">
      <div class="col-md-12">
        <h2 class="display-2">About the NZ ORCID Hub</h2>
        <p><br/>Work undertaken as part of the MBIE-led ORCID Working Group confirmed the view that New Zealand's
          research organisations exist in a wide range of sizes and ability to access IT support. As a consequence, the
          ability of organisations to respond to the ORCID Joint Statement of Principle that New Zealand adopt ORCID as
          the national researcher identifier also varied widely. In recognition that assisting all Consortia-eligible
          organisations to productively engage with ORCID would lead to national benefits, the Ministry has provided
          support for the development of the New Zealand ORCID Hub. As designed, the core function of the Hub is to
          provide all New Zealand ORCID Consortium members with the ability to make authoritative assertions of their
          elationship with researchers on the researcher's ORCID record, irrespective of their size or technical
          resource.</p>

        <p>Throughout 2017 to late 2019, this project is being developed by a team at the University of Auckland under
          contract to the Royal Society of New Zealand.  As the phenomena of small research organisations is not
          limited to New Zealand, it is a principle of the Hub's development that it be architected for use by the
          global ORCID community.  To support this design principle, development is being pursued in as transparent a
          nature as possible, with the Hub itself being developed under the permissive MIT License.</p>

        <p>The core development team at the University of Auckland consists of: jeff kennedy, Enterprise Architecture
          Manager; Radomirs Cirskis, ORCID Project Architect; and Roshan Pawar, ORCID Developer.</p>

        <p>The Hub's operates in two modes: self-service Tuakiri-member organisation login; and file upload either via
          a UI or the Hub's API.</p>
        <ul>
          <li>The Tuakiri login flow takes the information presented as part of the log in process and uses this to
            write a minimal affiliation of organisation, city, country and employment/education.  The benefit of the
            Tuakiri-style is that the affiliation is written though researcher interaction, with anyone having
            credentials at a Tuakiri-member organisation able to initiate this process.  This process is also very
            secure as the user's email and EPPN is authenticated as part of the exchange</li>
          <li>The File upload flow uses additional data provided by the organisation to write richer affiliations.  If
            the user has already logged in with Tuakiri, the affiliation written replaces the minimal affiliation item.
            If the Hub has no record of the individual, an email invitation is sent asking permission to write to their
            ORCID record, with receipt of permission resulting in the record being updated.  The advantage of this flow
            is that fewer user interactions are required, and the result is typically a richer affiliation.  It's also
            the only way non-Tuakiri members have for interacting with the Hub.  The disadvantage is that the ability
            of the user to receive the invitation is the only assurance of the user's identity.</li>
        </ul>

        <p>The Hub has been awarded the following Collect and Connect badges recognising it follows ORCID's
          recommendations for integrating with ORCID in these stages:</p>
      </div>
    </div>

    <div class="row">
      <div class="col-md-3">
      </div>
      <div class="col-md-6" style="text-align: center;">
        <img title="C&C Authenticate" src="{{url_for('static', filename='images/ORCID Badge AUTHENTICATE 2019.jpg')}}" alt="ORCID AUTHENTICATE Badge 2019" width="130" height="182">
        <img title="C&C Collect" src="{{url_for('static', filename='images/ORCID Badge COLLECT 2019.jpg')}}" alt="ORCID COLLECT Badge 2019" width="130" height="182">
        <img title="C&C Display" src="{{url_for('static', filename='images/ORCID Badge DISPLAY 2019.jpg')}}" alt="ORCID AUTHENTICATE DISPLAY 2019" width="130" height="182">
        <img title="C&C Connect" src="{{url_for('static', filename='images/ORCID Badge CONNECT 2019.jpg')}}" alt="ORCID CONNECT Badge 2019" width="130" height="182">
      </div>
    </div>
    <div class="row">
      <div class="col-md-12">
        <p>Any Consortium member who uses the NZ ORCID Hub qualifies for these four C&C badges.</p>

        <p>For more information on the Hub's background and links to resources please visit the
          <a href="https://royalsociety.org.nz/orcid-in-new-zealand/new-zealand-orcid-consortium/who-is-involved-with-the-new-zealand-orcid-consortium/new-zealand-orcid-hub/">Hub page</a>
          of the Royal Society Te Apārangi’s website.</p>

        <h2 class="display-2">Contact Details</h2>
        <address>
          Royal Society of New Zealand<br>
          Phone: +64 (04) 472 7421<br>
          PO Box 598, Wellington 6140<br>
          New Zealand<br>
          Email: <b><a href="mailto:orcid@royalsociety.org.nz">orcid@royalsociety.org.nz</a></b>
        </address>
      </div>
    </div>
  </div>

{% endblock %}
