{% extends "layout.html" %}
{% block content %}
  <div class="container">
    <div class="jumbotron">
      <h2 class="display-2">Welcome to NZ ORCID Hub</h2>
      <p>You had logged in from <strong>The University of Auckland</strong>. You have to close all open browser tabs and windows in order in order to complete the log-out (See: <a href="https://www.auckland.ac.nz/en/about/the-university/identity-and-access-management-help/about-single-sign-on.html"> About Single-Sign-On </a>)</p>
    </div>
  </div>
{% endblock %}
