<h2 class="display-2">Welcome to the NZ ORCID Hub</h2>
<p>Welcome!</p>
<p>You appear to have revoked permission for {{org_name}} to write to your ORCID record, </p>
<p>If you want this to happen you'll need to give them permission again...</p>
<p>Please click on the link below to login on ORCIDHUB via ORCID<br>
<a href="{{ invitation_url }}">{{ invitation_url }}</a><br>
<p>
Once you click this link, you'll be taken to ORCID to sign in to, or create, your ORCID record.
Once you've granted permission, you'll be automatically taken to the Hub.
Note no further action from you is needed.
In the next minute or so, the affiliation will be shown in your ORCID record.
</p>
